
/* Generated data (by glib-mkenums) */

#if !defined (__VTE_VTE_H_INSIDE__) && !defined (VTE_COMPILATION)
#error "Only <vte/vte.h> can be included directly."
#endif

#ifndef __VTE_VTE_TYPE_BUILTINS_H__
#define __VTE_VTE_TYPE_BUILTINS_H__

#include <glib-object.h>

#include "vtemacros.h"

G_BEGIN_DECLS

/* enumerations from "vteenums.h" */
_VTE_PUBLIC
GType vte_cursor_blink_mode_get_type (void);
#define VTE_TYPE_CURSOR_BLINK_MODE (vte_cursor_blink_mode_get_type ())
_VTE_PUBLIC
GType vte_cursor_shape_get_type (void);
#define VTE_TYPE_CURSOR_SHAPE (vte_cursor_shape_get_type ())
_VTE_PUBLIC
GType vte_erase_binding_get_type (void);
#define VTE_TYPE_ERASE_BINDING (vte_erase_binding_get_type ())
_VTE_PUBLIC
GType vte_pty_error_get_type (void);
#define VTE_TYPE_PTY_ERROR (vte_pty_error_get_type ())
_VTE_PUBLIC
GType vte_pty_flags_get_type (void);
#define VTE_TYPE_PTY_FLAGS (vte_pty_flags_get_type ())
_VTE_PUBLIC
GType vte_write_flags_get_type (void);
#define VTE_TYPE_WRITE_FLAGS (vte_write_flags_get_type ())
_VTE_PUBLIC
GType vte_regex_error_get_type (void);
#define VTE_TYPE_REGEX_ERROR (vte_regex_error_get_type ())
G_END_DECLS

#endif /* __VTE_VTE_TYPE_BUILTINS_H__ */

/* Generated data ends here */

